﻿//------------------------------------------------------------------------------
// <copyright file="MainWindow.xaml.cs" company="Microsoft">
//     Copyright (c) Microsoft Corporation.  All rights reserved.
// </copyright>
//------------------------------------------------------------------------------

namespace $safeprojectname$
{
    using System;
    using System.IO;
    using System.Windows;
    using System.Windows.Media;
    using Microsoft.Kinect;
    using System.Threading;

    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
       
        private const float RenderWidth = 640.0f;
        private const float RenderHeight = 480.0f;
        private const double JointThickness = 3;
        private const double BodyCenterThickness = 10;
        private const double ClipBoundsThickness = 10;
        private readonly Brush centerPointBrush = Brushes.Blue;
        private readonly Brush trackedJointBrush = new SolidColorBrush(Color.FromArgb(255, 68, 192, 68));
        private readonly Brush inferredJointBrush = Brushes.Yellow;
        private readonly Brush rightHandJointBrush = Brushes.Red;
        private readonly Pen trackedBonePen = new Pen(Brushes.Green, 6);
        private readonly Pen inferredBonePen = new Pen(Brushes.Gray, 1);
        private KinectSensor sensor;
        private DrawingGroup drawingGroup;
        private DrawingImage imageSource;
        private SkeletonPoint Position;
        private double x = 0, y = 0, z = 0;
        private Bd based;
        private Thread setpositionThread;
        private bool statusconnexion = false;
        private bool statusupdate;



        public MainWindow()
        {
            InitializeComponent();
                                                   
        }
        
        public void setposition()
        {
            
            if(statusconnexion)
            {
                while (true)
                {
                   
                    if (statusconnexion)
                    {
                        statusupdate = based.update(this.z, this.y);
                    }
                    if (!statusupdate)
                    {
                        info.Text = "Erreur update bd";
                    }
            
                
                    Thread.Sleep(5000);
               }
            }
 
        }

        private void WindowLoaded(object sender, RoutedEventArgs e)
        {
            this.drawingGroup = new DrawingGroup();

            this.imageSource = new DrawingImage(this.drawingGroup);
                        
            Image.Source = this.imageSource;
                        
            foreach (var potentialSensor in KinectSensor.KinectSensors)
            {
                if (potentialSensor.Status == KinectStatus.Connected)
                {
                    this.sensor = potentialSensor;
                    break;
                }
            }

            if (null != this.sensor)
            {
                
                this.sensor.SkeletonStream.Enable();

                this.sensor.SkeletonFrameReady += this.SensorSkeletonFrameReady;

                // Start the sensor!
                try
                {
                    this.sensor.Start();
                    info.Text += "Début de tracking\n";
                }
                catch (IOException)
                {
                    this.sensor = null;
                }
            }

            if (null == this.sensor)
            {
                info.Text += "kinect non branchée\n";
            }

            
            based = new Bd();
            statusconnexion = based.getConnexion();

            if (!statusconnexion)
            {
                info.Text = "Erreur de connexion à la base de donnée\n";
            }
            else
                info.Text += "Connexion à la base de donnée réussi\n";

            
            ThreadStart setpositionref = new ThreadStart(setposition);
            setpositionThread = new Thread(setpositionref);
            setpositionThread.Start();
        }

        private void WindowClosing(object sender, System.ComponentModel.CancelEventArgs e)
        {
            if (null != this.sensor)
            {
                this.sensor.Stop();
            }
            setpositionThread.Abort();
            
        }
        
        private void SensorSkeletonFrameReady(object sender, SkeletonFrameReadyEventArgs e)
        {
            Skeleton[] skeletons = new Skeleton[0];

            using (SkeletonFrame skeletonFrame = e.OpenSkeletonFrame())
            {
                if (skeletonFrame != null)
                {
                    skeletons = new Skeleton[skeletonFrame.SkeletonArrayLength];
                    skeletonFrame.CopySkeletonDataTo(skeletons);
                }
            }

            using (DrawingContext dc = this.drawingGroup.Open())
            {
                // Draw a transparent background to set the render size
                dc.DrawRectangle(Brushes.Black, null, new Rect(0.0, 0.0, RenderWidth, RenderHeight));

                if (skeletons.Length != 0)
                {
                    foreach (Skeleton skel in skeletons)
                    {
                        this.DrawBonesAndJoints(skel, dc);
                    }
                }

                // prevent drawing outside of our render area
                this.drawingGroup.ClipGeometry = new RectangleGeometry(new Rect(0.0, 0.0, RenderWidth, RenderHeight));
            }
        }
        
        private void DrawBonesAndJoints(Skeleton skeleton, DrawingContext drawingContext)
        {
            
            // Render Torso            
            this.DrawBone(skeleton, drawingContext, JointType.Head, JointType.ShoulderCenter);
            this.DrawBone(skeleton, drawingContext, JointType.ShoulderCenter, JointType.ShoulderLeft);
            this.DrawBone(skeleton, drawingContext, JointType.ShoulderCenter, JointType.ShoulderRight);
            this.DrawBone(skeleton, drawingContext, JointType.ShoulderCenter, JointType.Spine);
            this.DrawBone(skeleton, drawingContext, JointType.Spine, JointType.HipCenter);
            this.DrawBone(skeleton, drawingContext, JointType.HipCenter, JointType.HipLeft);
            this.DrawBone(skeleton, drawingContext, JointType.HipCenter, JointType.HipRight);
            
            // Left Arm
            this.DrawBone(skeleton, drawingContext, JointType.ShoulderLeft, JointType.ElbowLeft);
            this.DrawBone(skeleton, drawingContext, JointType.ElbowLeft, JointType.WristLeft);
            this.DrawBone(skeleton, drawingContext, JointType.WristLeft, JointType.HandLeft);
             

            
            // Right Arm
            this.DrawBone(skeleton, drawingContext, JointType.ShoulderRight, JointType.ElbowRight);
            this.DrawBone(skeleton, drawingContext, JointType.ElbowRight, JointType.WristRight);
            this.DrawBone(skeleton, drawingContext, JointType.WristRight, JointType.HandRight);

            
            // Left Leg
            this.DrawBone(skeleton, drawingContext, JointType.HipLeft, JointType.KneeLeft);
            this.DrawBone(skeleton, drawingContext, JointType.KneeLeft, JointType.AnkleLeft);
            this.DrawBone(skeleton, drawingContext, JointType.AnkleLeft, JointType.FootLeft);

            // Right Leg
            this.DrawBone(skeleton, drawingContext, JointType.HipRight, JointType.KneeRight);
            this.DrawBone(skeleton, drawingContext, JointType.KneeRight, JointType.AnkleRight);
            this.DrawBone(skeleton, drawingContext, JointType.AnkleRight, JointType.FootRight);
            
             
 

            // Render Joints
            foreach (Joint joint in skeleton.Joints)
            {
                Brush drawBrush = null;

                if (joint.TrackingState == JointTrackingState.Tracked)
                {

                    if (joint.JointType == JointType.HandRight)
                    {
                        drawBrush = this.rightHandJointBrush;
                        this.Position = joint.Position;
                        this.x = this.Position.X;
                        this.y = this.Position.Y;
                        this.z = this.Position.Z;
                                                
                        xvalue.Text = String.Format("{0:0.00}", this.x);
                        yvalue.Text = String.Format("{0:0.00}", this.y);
                        zvalue.Text = String.Format("{0:0.00}", this.z);

                        getZone(this.z, this.y);
                        
                    }
                    else
                        drawBrush = this.trackedJointBrush;

                }
                


                if (drawBrush != null)
                {
                    drawingContext.DrawEllipse(drawBrush, null, this.SkeletonPointToScreen(joint.Position), JointThickness, JointThickness);
                }
            }
        }
        
        private Point SkeletonPointToScreen(SkeletonPoint skelpoint)
        {
            DepthImagePoint depthPoint = this.sensor.CoordinateMapper.MapSkeletonPointToDepthPoint(skelpoint, DepthImageFormat.Resolution640x480Fps30);
            return new Point(depthPoint.X, depthPoint.Y);
        }

        private void DrawBone(Skeleton skeleton, DrawingContext drawingContext, JointType jointType0, JointType jointType1)
        {
            Joint joint0 = skeleton.Joints[jointType0];
            Joint joint1 = skeleton.Joints[jointType1];

            // If we can't find either of these joints, exit
            if (joint0.TrackingState == JointTrackingState.NotTracked ||
                joint1.TrackingState == JointTrackingState.NotTracked)
            {
                return;
            }

            // Don't draw if both points are inferred
            if (joint0.TrackingState == JointTrackingState.Inferred &&
                joint1.TrackingState == JointTrackingState.Inferred)
            {
                return;
            }

            // We assume all drawn bones are inferred unless BOTH joints are tracked
            Pen drawPen = this.inferredBonePen;
            if (joint0.TrackingState == JointTrackingState.Tracked && joint1.TrackingState == JointTrackingState.Tracked)
            {
                drawPen = this.trackedBonePen;
            }

            drawingContext.DrawLine(drawPen, this.SkeletonPointToScreen(joint0.Position), this.SkeletonPointToScreen(joint1.Position));
        }

        private void getZone(double z, double y)
        {
            //zone 1
            if ((z > 1) && (z < 1.3) && ( y > 0.15) && ( y < 0.45))
                zone.Text = "zone 1";

            //zone 2
            if ((z > 1.3) && (z < 1.6) && (y > 0.15) && (y < 0.45))
                zone.Text = "zone 2";

            //zone 3
            if ((z > 1.6) && (z < 1.9) && (y > 0.15) && (y < 0.45))
                zone.Text = "zone 3";

            //zone 4
            if ((z > 1) && (z < 1.3) && (y > -0.15) && (y < 0.15))
                zone.Text = "zone 4";


            //zone 5
            if ((z > 1.3) && (z < 1.6) && (y > -0.15) && (y < 0.15))
                zone.Text = "zone 5";


            //zone 6
            if ((z > 1.6) && (z < 1.9) && (y > -0.15) && (y < 0.15))
                zone.Text = "zone 6";

            //zone 7
            if ((z > 1) && (z < 1.3) && (y > -0.45) && (y < -0.15))
                zone.Text = "zone 7";

            //zone 8
            if ((z > 1.3) && (z < 1.6) && (y > -0.45) && (y < -0.15))
                zone.Text = "zone 8";

            //zone 9
            if ((z > 1.6) && (z < 1.9) && (y > -0.45) && (y < -0.15))
                zone.Text = "zone 9";

        }
                        
    }
}